summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRobert Marklund <robert.marklund@stericsson.com>2011-10-26 09:59:03 +0200
committerPhilippe Langlais <philippe.langlais@stericsson.com>2012-05-22 11:04:09 +0200
commit9f600531b75ea87370826a6e1b5e0a692146eeb6 (patch)
tree1941b96be8080aae38f0515a7ddb243dc1d43930
parent558d296a33f73252a4c99ad83804ccd5f747b5ab (diff)
ux500: mcde: Dont probe for uib on snowball
To make startup a little faster dont probe for uib on snowball. Change-Id: I4fa592dfbb924fb84f0f3f80675ab0229527615e Signed-off-by: Robert Marklund <robert.marklund@stericsson.com> Reviewed-on: http://gerrit.lud.stericsson.com/gerrit/35353 Reviewed-by: Philippe LANGLAIS <philippe.langlais@stericsson.com>
-rw-r--r--arch/arm/mach-ux500/board-mop500-mcde.c29
1 files changed, 17 insertions, 12 deletions
diff --git a/arch/arm/mach-ux500/board-mop500-mcde.c b/arch/arm/mach-ux500/board-mop500-mcde.c
index 9e967f72138..efddf193e5f 100644
--- a/arch/arm/mach-ux500/board-mop500-mcde.c
+++ b/arch/arm/mach-ux500/board-mop500-mcde.c
@@ -712,18 +712,23 @@ int __init init_display_devices(void)
generic_display0_pdata.reset_gpio = MOP500_DISP1_RST_GPIO;
#ifdef CONFIG_DISPLAY_GENERIC_DSI_PRIMARY_VSYNC
- i2c0 = i2c_get_adapter(0);
- if (i2c0) {
- /*
- * U8500-UIB has the TC35893 at 0x44 on I2C0, the
- * ST-UIB has not.
- */
- ret = i2c_smbus_xfer(i2c0, 0x44, 0, I2C_SMBUS_WRITE, 0,
- I2C_SMBUS_QUICK, NULL);
- i2c_put_adapter(i2c0);
-
- /* ret == 0 => U8500 UIB connected */
- generic_display0.synchronized_update = (ret == 0);
+ if (!machine_is_snowball()) {
+ i2c0 = i2c_get_adapter(0);
+ if (i2c0) {
+ /*
+ * U8500-UIB has the TC35893 at 0x44 on I2C0, the
+ * ST-UIB has not.
+ */
+ ret = i2c_smbus_xfer(i2c0, 0x44, 0, I2C_SMBUS_WRITE, 0,
+ I2C_SMBUS_QUICK, NULL);
+ i2c_put_adapter(i2c0);
+
+ /* ret == 0 => U8500 UIB connected */
+ generic_display0.synchronized_update = (ret == 0);
+ }
+ } else {
+ /* Snowball dont have uib */
+ generic_display0.synchronized_update = 0;
}
#endif